@@ -468,7 +468,7 @@ create_admin_section (IndicatorSessionService * self)
   if (p->usage_mode_action && g_getenv ("MIR_SOCKET") != NULL) // only under unity8
   {
       GMenuItem * menu_item = NULL;
-      menu_item = g_menu_item_new(_("Desktop mode"), "indicator.usage-mode");
+      menu_item = g_menu_item_new(_("Desktop Mode"), "indicator.usage-mode");
       g_menu_item_set_attribute(menu_item, "x-canonical-type", "s", "com.canonical.indicator.switch");
       g_menu_append_item(menu, menu_item);
       g_object_unref(menu_item);
@@ -716,9 +716,20 @@ create_switch_section (IndicatorSessionService * self, int profile)
     {
       if (want_accel)
         {
-          gchar * str = g_settings_get_string (p->keybinding_settings, "screensaver");
-          g_menu_item_set_attribute (item, "accel", "s", str);
-          g_free (str);
+          GVariant * value = g_settings_get_value (p->keybinding_settings, "screensaver");
+          if (g_variant_is_of_type (value, G_VARIANT_TYPE_STRING_ARRAY))
+            {
+              const gchar ** strs = g_variant_get_strv (value, NULL);
+              if (strs)
+                g_menu_item_set_attribute (item, "accel", "s", strs[0]);
+              g_free (strs);
+            }
+          else
+            {
+              const gchar * str = g_variant_get_string (value, NULL);
+              g_menu_item_set_attribute (item, "accel", "s", str);
+            }
+          g_variant_unref (value);
         }
 
       g_menu_append_item (menu, item);
@@ -1280,6 +1291,33 @@ on_name_lost (GDBusConnection * connection G_GNUC_UNUSED,
   g_signal_emit (self, signals[NAME_LOST], 0, NULL);
 }
 
+static gboolean
+desktop_is_unity (void)
+{
+  const gchar * xdg_current_desktop;
+  gchar ** desktop_names;
+  int i;
+
+  xdg_current_desktop = g_getenv ("XDG_CURRENT_DESKTOP");
+
+  if (xdg_current_desktop == NULL)
+    return FALSE;
+
+  desktop_names = g_strsplit (xdg_current_desktop, ":", 0);
+
+  for (i = 0; desktop_names[i]; ++i)
+    {
+      if (g_strcmp0 (desktop_names[i], "Unity") == 0)
+        {
+          g_strfreev (desktop_names);
+          return TRUE;
+        }
+    }
+
+  g_strfreev (desktop_names);
+  return FALSE;
+}
+
 /***
 ****
 ***/
@@ -1298,7 +1336,10 @@ indicator_session_service_init (IndicatorSessionService * self)
                                    INDICATOR_TYPE_SESSION_SERVICE,
                                    IndicatorSessionServicePrivate);
   p->indicator_settings = g_settings_new ("com.canonical.indicator.session");
-  p->keybinding_settings = g_settings_new ("org.gnome.settings-daemon.plugins.media-keys");
+  if (desktop_is_unity ())
+    p->keybinding_settings = g_settings_new ("com.canonical.unity.settings-daemon.plugins.media-keys");
+  else
+    p->keybinding_settings = g_settings_new ("org.gnome.settings-daemon.plugins.media-keys");
 
   /* Only use unity8 schema if it's installed; this avoids a hard dependency
      on unity8-schemas */
